# Cookiecutter-seatools-python-chrome

Cookiecutter-seatools-python chrome拓展工具包

## 仓库地址:
1. https://github.com/seatools-py/cookiecutter-seatools-python-chrome
2. https://gitee.com/seatools-py/cookiecutter-seatools-python-chrome

## Cookiecutter-seatools-python 模板项目地址
1. https://github.com/seatools-py/cookiecutter-seatools-python
2. https://gitee.com/seatools-py/cookiecutter-seatools-python

## Seatools 工具包地址
1. https://github.com/seatools-py/seatools
2. https://gitee.com/seatools-py/seatools
